// TrapezoidalWalkway.java

// 2013 ACM North American Qualifier contest
// Solution by Irvine

import java.util.*;
import java.io.*;

class Vertex implements Comparable<Vertex>
{
    public String name = null;
    public List<Edge> adj;
    public double minDistance = Double.POSITIVE_INFINITY;
    public Vertex previous;
    public boolean visited;
    int width;			// width of one side of a tile
        
    public Vertex(int width) {
   	 this.width = width;
   	 visited = false;
   	 adj = new LinkedList<Edge>();
    }

    public Vertex(String argName) { 
    	name = argName; 
    }
    
    // cost of a tile is .02 per square centimeter

    public String toString() 
    { 
    	if( minDistance < 10000000.0)
    		return String.format("(%d, %.2f)", width, minDistance);
    	else
    		return String.format("(%d, <inf>)", width);
    }

    
    public String toString(boolean showEdges) 
    { 
   	 //String temp = String.format("(%d, %.2f)", width, minDistance);
   	 String temp = String.format("%d-->", width);   	 
   	 
   	 for( Edge e : adj) {
   		 temp += e.toString() + ", ";
   	 }
   	 return temp;
    }

    public int compareTo(Vertex other)   {
        return Double.compare(minDistance, other.minDistance);
    }
}  // vertex class

class Edge {
    public final Vertex target;
    public final double weight;

    public Edge(Vertex argTarget, double argWeight)  { 
    	target = argTarget; 
    	weight = argWeight; 
    }
     
    public String toString() {
   	 return String.format("(%s, %.2f)", target, weight); 
    }
}

public class TrapezoidWalkway
{
	 Scanner in;
	 Map<Integer, Vertex> vertices;
	 
	 // Compute shortest path from the source node to all other nodes, 
	 // using Dijkstra's algorithm.

    public static void computePaths(Vertex source)
    {
        source.minDistance = 0.;
        PriorityQueue<Vertex> vertexQueue = new PriorityQueue<Vertex>();
        vertexQueue.add(source);

        while (!vertexQueue.isEmpty()) {

        	Vertex u = vertexQueue.poll();   // retrieve and remove the head element
        	//System.out.printf("removed vertex u: %s\n", u);

            // Visit each edge exiting u
            for (Edge e : u.adj)
            {
                Vertex v = e.target;
                double weight = e.weight;
                double distanceThroughU = u.minDistance + weight;
                
                if (distanceThroughU < v.minDistance) {
                	vertexQueue.remove(v);    // v may not be in the queue, but that's okay
                	v.minDistance = distanceThroughU ;
                	//System.out.printf("\tUpating v's minDistance: %s\n", v);
                	v.previous = u;
                	vertexQueue.add(v);   // because now its minDistance has changed
                }  // if

            }   // for each edge in u's adjacency list
        }  // while queue is not empty
    }  // computePaths

    public static List<Vertex> getShortestPathTo(Vertex target)
    {
		// Build a list by starting at the target vertex, and work backward through
		// the path using the <previous> link in each vertex back to the source 
		// vertex. Then reverse and return the list.
		List<Vertex> path = new ArrayList<Vertex>();
        for (Vertex vertex = target; vertex != null; vertex = vertex.previous)
           path.add(vertex);
        Collections.reverse(path);
        return path;
    }
  
	void printVertices() {			// just for debugging
		 System.out.println("---------- Vertices ------------");
	   	 for( Vertex v : vertices.values() ) {
	   		 System.out.printf("%s\n", v.toString(true));
	   	 }
    }
       
	// the cost of a tile is 2 cents times the trapezoidal area.   
    double calculateCost(int sideA, int sideB, int height ) {
     	 double area = height * (sideA + sideB) / 2.0;
     	 return area * .02;
   }   
    
    Vertex getVertex( int width )  { 	 
   	 if( !vertices.containsKey(width)) {
   		 vertices.put(width, new Vertex(width));
   	 }
   	 return vertices.get(width);
    }   
    
    void start() throws Exception {
   	 
   	 //in = new Scanner(new File("trapezoidal.judge.in.txt"));
   	 in = new Scanner(System.in);

   	 
   	 int numStones = in.nextInt();
   	 while( numStones > 0 )  {
   		 
   		 vertices = new HashMap<Integer, Vertex>();
   		 
   		 for(int k = 0; k < numStones; k++)  {
	   		 int sideA = in.nextInt();
	   		 int sideB = in.nextInt();
	   		 int height = in.nextInt();
	   		 double cost = calculateCost(sideA, sideB, height);
	   		 // The mistake I made at first was to create new vertices for
	   		 // sideA and sideB. Instead, it's important to look for existing
	   		 // vertices that match the widths of sideA and sideB and use them if they exist.	   		 
	   		 
	   		 // add bidirectional edges between the two vertices
	   		 getVertex(sideA).adj.add(new Edge(getVertex(sideB), cost));
	   		 getVertex(sideB).adj.add(new Edge(getVertex(sideA), cost));   		 
	   	 }  // for k
   		 
   		 int porchWidth = in.nextInt();
   		 Vertex vp = new Vertex(0);	// add a vertex for the porch width
   		 vertices.put(0, vp);
   		 
   		 // find vertex that equals the width of the porch, and add it to
   		 // the porch's adjacency list
   		 vp.adj.add(new Edge( getVertex(porchWidth), 0));
   		    		   		    		 
   		 int gazeboWidth = in.nextInt();
   		 vp = new Vertex(9999);			// add a vertex for the porch (width unimportant)
   		 
   		 // find the vertex that matches the width of the porch
   		 vertices.get(gazeboWidth).adj.add(new Edge(vp,0));	 
  		    		 
   		 // printVertices();					// only for debugging
   		 computePaths(vertices.get(0));  // the porch

   		 System.out.printf("%.2f\n", vp.minDistance);

   		 //System.out.printf("Distance to %s: %.2f\n", vp, vp.minDistance);
   		 //System.out.println("Path: " + getShortestPathTo(vp));

    	 	/*  Use this if you want to the weights of all the vertices
   		 for (Vertex v : vertices.values())
 			{
    	 		System.out.printf("Distance to %s: %.2f\n", v, v.minDistance);
 			   List<Vertex> path = getShortestPathTo(v);
 			   System.out.println("Path: " + path);
 			}*/
        	          	   	 
	   	 numStones = in.nextInt();  // ready for next test case
   	 } // while
   	 
    }  // start
    
    public static void main(String[] args) throws Exception  {
   	 new TrapezoidWalkway().start();
    }
}  // class